/***************************************************

Creator:    Elior

Created:	Febuary 2014

Description: This file creates Table 3:Difference in 
		     Differences Estimates
			
*****************************************************/

clear all
set mem 500m
set matsize 800
set more off
set logtype text

global name Table_3 

local today="$S_DATE"
local day=word("`today'",1)
local month=word("`today'",2)
local year=substr(word("`today'",3),3,2)
if `day'<10 local day="0`day'" 

/**************************************************
I. ENTER THE PATH NAME WHERE THE DATA FILE IS FOUND
**************************************************/
cd "C:\Users\msvictor3\Dropbox\Work\Kibbutzim\Kibbutzim_ECMA"

use data\kibbutzim, clear

/*******************************************
II. Define `after' and `before'
*******************************************/
local act9596_9900Before "1995 1996"
local act9596_9900After "1999 2000"

local plac9596_9798Before "1995 1996"
local plac9596_9798After "1997 1998"

/*******************************************
III. Define samples
*******************************************/
//FULL SAMPLE
local allobs "id !=."

//By gender
gen girl = (boy == 0)

//By maternal education 
gen motH = (educ_em >= 14)

/*******************************************
IV. Run DID regresssions - PART I
*******************************************/
local depvars "graduate wmean zakai_bagrut university score"
local controls "boy educ_av educ_em m_ahim eth_*"
local reform_dummies "d_pay_meal d_pay_electricity d_pay_health d_pay_laundry" 

local cluster "cluster(kibbutz)"

local tgroups "ref9800"

local cgroups "ref0304"

local samples "allobs"

local sets "act9596_9900"

*******Open log******* 
cap log close
log using "logs\\${name}_`day'`month'`year'.log", replace
**********************

postfile values str50 rowKey graduate1 wmean1 zakai_bagrut1 university1 score1 gap graduate2 wmean2 zakai_bagrut2 university2 score2  using "results\automatic\\${name}", replace

foreach treatment in `tgroups'  {

	foreach control in `cgroups' {

		foreach sample in `samples' {

			foreach set in `sets' {

				//Define after and before periods
				cap drop after
				cap drop before
				cap drop treatment
				cap drop control
				cap drop afterXtreatment
				cap drop yearRelevant
				cap drop _Iyear*

				egen after  = anymatch(year), values(``set'After')
				egen before = anymatch(year), values(``set'Before')

				gen treatment=`treatment'
				gen control=`control'
				gen afterXtreatment = after*treatment

				//Create year dummies
				di ""
				di "gen yearRelevant = year if (before | after)"	
				gen yearRelevant = year if (before | after)

				di ""
				di "xi i.yearRelevant"
				xi i.yearRelevant

					foreach var of varlist `depvars' {

						// Simple DID
						di ""
						di "**********************************************************************************"
						di ""
						di "Simple DID"
						di ""
						di "Outcome: `var'"
						di ""
						di "Cohorts: ``set'After', ``set'Before'"
						di ""
						di "Sample: `sample'"
						di ""
						di "**********************************************************************************"
						di ""
						di "reg `var' after treatment afterXtreatment  _Iyear* if (before | after) & (treatment==1| control==1) & ``sample'', `cluster'"
						reg `var' after treatment afterXtreatment  _Iyear* if (before | after) & (treatment==1| control==1) & ``sample'', `cluster'
						
						local B1_`var'_`set'  = _b[afterXtreatment]
						local SE1_`var'_`set' = _se[afterXtreatment]

						//DID + year dummies + individual controls + kibbutz FE
						di ""
						di "**********************************************************************************"
						di ""
						di "DID + year dummies + individual controls + kibbutz FE"
						di ""
						di "Outcome: `var'"
						di ""
						di "Cohorts: ``set'After', ``set'Before'"
						di ""
						di "Sample: `sample'"
						di ""
						di "**********************************************************************************"
						di ""
						di "areg `var' afterXtreatment _Iyear* `controls' if (before | after) & (treatment==1| control==1) & ``sample'', absorb(kibbutz) `cluster'"
						areg `var' afterXtreatment _Iyear* `controls'  if (before | after) & (treatment==1| control==1) & ``sample'', absorb(kibbutz) `cluster'
						
						local B2_`var'_`set'  = _b[afterXtreatment]
						local SE2_`var'_`set' = _se[afterXtreatment]
						
						* INCLUDING REFORM DUMMIES AS CONTROLS IN THE DID REGRESSION
						di "areg `var' afterXtreatment _Iyear* `controls' `reform_dummies' if (before | after) & (treatment==1| control==1) & ``sample'', absorb(kibbutz) `cluster'"
						areg `var' afterXtreatment _Iyear* `controls' `reform_dummies'  if (before | after) & (treatment==1| control==1) & ``sample'', absorb(kibbutz) `cluster'
						
						local B3_`var'_`set'  = _b[afterXtreatment]
						local SE3_`var'_`set' = _se[afterXtreatment]
						
						if `var' == graduate | `var' == zakai_bagrut | `var' == university {
						
						//PROBIT DID + year dummies + individual controls + kibbutz FE
						di ""
						di "**********************************************************************************"
						di ""
						di "PROBIT DID + year dummies + individual controls + kibbutz FE"
						di ""
						di "Outcome: `var'"
						di ""
						di "Cohorts: ``set'After', ``set'Before'"
						di ""
						di "Sample: `sample'"
						di ""
						di "**********************************************************************************"
						di ""
						di "xi: dprobit `var' afterXtreatment `controls' i.year i.kibbutz  if (before | after) & (treatment==1| control==1) & ``sample'', `cluster'"
						xi: dprobit `var' afterXtreatment `controls' i.year i.kibbutz  if (before | after) & (treatment==1| control==1) & ``sample'', `cluster'
						
						matrix define A = e(dfdx)
						matrix define B = e(se_dfdx)
						
						local B4_`var'_`set'  = A[1,1]
						local SE4_`var'_`set' = B[1,1]
						
						* INCLUDING REFORM DUMMIES AS CONTROLS IN THE DID REGRESSION
						di "xi: dprobit `var' afterXtreatment `controls' `reform_dummies' i.year i.kibbutz  if (before | after) & (treatment==1| control==1) & ``sample'', `cluster'"
						xi: dprobit `var' afterXtreatment `controls' `reform_dummies' i.year i.kibbutz  if (before | after) & (treatment==1| control==1) & ``sample'', `cluster'
						
						matrix define A = e(dfdx)
						matrix define B = e(se_dfdx)
						
						local B5_`var'_`set'  = A[1,1]
						local SE5_`var'_`set' = B[1,1]
						}
						

				}		
				
			}
		}
	}
}


post values ("Simple DID act")	     (`B1_graduate_act9596_9900')  (`B1_wmean_act9596_9900')    (`B1_zakai_bagrut_act9596_9900')    (`B1_university_act9596_9900') (`B1_score_act9596_9900') (.) (.) (.) (.) (.) (.)  
post values ("cluster SE")	         (`SE1_graduate_act9596_9900') (`SE1_wmean_act9596_9900')   (`SE1_zakai_bagrut_act9596_9900')   (`SE1_university_act9596_9900') (`SE1_score_act9596_9900') (.) (.) (.) (.) (.) (.)
post values ("")                     (.)		       			   (.)		     				(.)                   				(.)                              (.)                        (.) (.) (.) (.) (.) (.)			  


post values ("Controlled DID act")	 (`B2_graduate_act9596_9900')  (`B2_wmean_act9596_9900')    (`B2_zakai_bagrut_act9596_9900')    (`B2_university_act9596_9900') (`B2_score_act9596_9900')   (.) (`B3_graduate_act9596_9900')  (`B3_wmean_act9596_9900')    (`B3_zakai_bagrut_act9596_9900')    (`B3_university_act9596_9900') (`B3_score_act9596_9900')  
post values ("cluster SE")	         (`SE2_graduate_act9596_9900') (`SE2_wmean_act9596_9900')   (`SE2_zakai_bagrut_act9596_9900')   (`SE2_university_act9596_9900') (`SE2_score_act9596_9900') (.) (`SE3_graduate_act9596_9900') (`SE3_wmean_act9596_9900')   (`SE3_zakai_bagrut_act9596_9900')   (`SE3_university_act9596_9900') (`SE3_score_act9596_9900')
post values ("")                     (.)		       			   (.)		     				(.)                   				(.)			                     (.)                       (.)                        (.) (.) (.) (.) (.) 	

post values ("PROBIT DID act")	     (`B4_graduate_act9596_9900')  (.)    (`B4_zakai_bagrut_act9596_9900')    (`B4_university_act9596_9900')  (.)   (.) (`B5_graduate_act9596_9900')  (.)    (`B5_zakai_bagrut_act9596_9900')    (`B5_university_act9596_9900') (.) 
post values ("cluster SE")	         (`SE4_graduate_act9596_9900') (.)   (`SE4_zakai_bagrut_act9596_9900')    (`SE4_university_act9596_9900') (.) (.) (`SE5_graduate_act9596_9900') (.)   (`SE5_zakai_bagrut_act9596_9900')   (`SE5_university_act9596_9900') (.)
post values ("")                     (.)		       			   (.)		     				(.)                   				(.) (.)  (.) (.) (.) (.) (.) (.) 			  

/*******************************************
IV. Run DID regresssions - PART II
*******************************************/
local depvars "graduate wmean zakai_bagrut university score"
local controls "boy educ_av educ_em m_ahim eth_*"
local reform_dummies "d_pay_meal d_pay_electricity d_pay_health d_pay_laundry" 

local cluster "cluster(kibbutz)"

local tgroups "ref9800"

local cgroups "ref0304"

local samples "allobs"

local sets "plac9596_9798"

foreach treatment in `tgroups'  {

	foreach control in `cgroups' {

		foreach sample in `samples' {

			foreach set in `sets' {

				//Define after and before periods
				cap drop after
				cap drop before
				cap drop treatment
				cap drop control
				cap drop afterXtreatment
				cap drop yearRelevant
				cap drop _Iyear*

				egen after  = anymatch(year), values(``set'After')
				egen before = anymatch(year), values(``set'Before')

				gen treatment=`treatment'
				gen control=`control'
				gen afterXtreatment = after*treatment

				//Create year dummies
				di ""
				di "gen yearRelevant = year if (before | after)"	
				gen yearRelevant = year if (before | after)

				di ""
				di "xi i.yearRelevant"
				xi i.yearRelevant

					foreach var of varlist `depvars' {

						// Simple DID
						di ""
						di "**********************************************************************************"
						di ""
						di "Simple DID"
						di ""
						di "Outcome: `var'"
						di ""
						di "Cohorts: ``set'After', ``set'Before'"
						di ""
						di "Sample: `sample'"
						di ""
						di "**********************************************************************************"
						di ""
						di "reg `var' after treatment afterXtreatment  _Iyear* if (before | after) & (treatment==1| control==1) & ``sample'', `cluster'"
						reg `var' after treatment afterXtreatment  _Iyear* if (before | after) & (treatment==1| control==1) & ``sample'', `cluster'
						
						local B1_`var'_`set'  = _b[afterXtreatment]
						local SE1_`var'_`set' = _se[afterXtreatment]

						//DID + year dummies + individual controls + kibbutz FE
						di ""
						di "**********************************************************************************"
						di ""
						di "DID + year dummies + individual controls + kibbutz FE"
						di ""
						di "Outcome: `var'"
						di ""
						di "Cohorts: ``set'After', ``set'Before'"
						di ""
						di "Sample: `sample'"
						di ""
						di "**********************************************************************************"
						di ""
						di "areg `var' afterXtreatment _Iyear* `controls' if (before | after) & (treatment==1| control==1) & ``sample'', absorb(kibbutz) `cluster'"
						areg `var' afterXtreatment _Iyear* `controls'  if (before | after) & (treatment==1| control==1) & ``sample'', absorb(kibbutz) `cluster'
						
						local B2_`var'_`set'  = _b[afterXtreatment]
						local SE2_`var'_`set' = _se[afterXtreatment]
						
						* INCLUDING REFORM DUMMIES AS CONTROLS IN THE DID REGRESSION
						di "areg `var' afterXtreatment _Iyear* `controls' `reform_dummies' if (before | after) & (treatment==1| control==1) & ``sample'', absorb(kibbutz) `cluster'"
						areg `var' afterXtreatment _Iyear* `controls' `reform_dummies'  if (before | after) & (treatment==1| control==1) & ``sample'', absorb(kibbutz) `cluster'
						
						local B3_`var'_`set'  = _b[afterXtreatment]
						local SE3_`var'_`set' = _se[afterXtreatment]
						

				}		
				
			}
		}
	}
}


post values ("Simple DID plac")	     (`B1_graduate_plac9596_9798')  (`B1_wmean_plac9596_9798')    (`B1_zakai_bagrut_plac9596_9798')    (`B1_university_plac9596_9798') (`B1_score_plac9596_9798') (.) (.) (.) (.) (.) (.)  
post values ("cluster SE")	         (`SE1_graduate_plac9596_9798') (`SE1_wmean_plac9596_9798')   (`SE1_zakai_bagrut_plac9596_9798')   (`SE1_university_plac9596_9798') (`SE1_score_plac9596_9798') (.) (.) (.) (.) (.) (.)
post values ("")                     (.)		       			   (.)		     				(.)                   				(.)                              (.)                        (.) (.) (.) (.) (.) (.)			  

post values ("Controlled DID plac")	 (`B2_graduate_plac9596_9798')  (`B2_wmean_plac9596_9798')    (`B2_zakai_bagrut_plac9596_9798')    (`B2_university_plac9596_9798') (`B2_score_plac9596_9798')   (.) (`B3_graduate_plac9596_9798')  (`B3_wmean_plac9596_9798')    (`B3_zakai_bagrut_plac9596_9798')    (`B3_university_plac9596_9798') (`B3_score_plac9596_9798')  
post values ("cluster SE")	         (`SE2_graduate_plac9596_9798') (`SE2_wmean_plac9596_9798')   (`SE2_zakai_bagrut_plac9596_9798')   (`SE2_university_plac9596_9798') (`SE2_score_plac9596_9798') (.) (`SE3_graduate_plac9596_9798') (`SE3_wmean_plac9596_9798')   (`SE3_zakai_bagrut_plac9596_9798')   (`SE3_university_plac9596_9798') (`SE3_score_plac9596_9798')
post values ("")                     (.)		       			   (.)		     				(.)                   				(.)			                     (.)                       (.)                        (.) (.) (.) (.) (.) 	


/*******************************************
IV. Run DID regresssions - PART III
*******************************************/
local depvars "graduate wmean zakai_bagrut university score"
local controls "boy educ_av educ_em m_ahim eth_*"
local reform_dummies "d_pay_meal d_pay_electricity d_pay_health d_pay_laundry" 

local cluster "cluster(kibbutz)"

local tgroups "ref9800"

local cgroups "ref0304"

local samples "motH girl"

local sets "act9596_9900"

foreach treatment in `tgroups'  {

	foreach control in `cgroups' {

		foreach set in `sets' {
		
			//Define after and before periods
			cap drop after
			cap drop before
			cap drop treatment
			cap drop control
			cap drop afterXtreatment
			cap drop yearRelevant
			cap drop _Yyear*

			egen after  = anymatch(year), values(``set'After')
			egen before = anymatch(year), values(``set'Before')

			gen treatment=`treatment'
			gen control=`control'
			gen afterXtreatment = after*treatment

			//Create year dummies
			di ""
			di "gen yearRelevant = year if (before | after)"		
			gen yearRelevant = year if (before | after)

			di ""
			di "xi i.yearRelevant"
			xi i.yearRelevant , prefix(_Y)

			//Create kibbutz dummies
			cap drop Rel
			gen Rel = kibbutz if (before==1 | after==1) & (treatment==1 | control==1)
			xi i.Rel, prefix(_Kib)

			foreach sample in `samples' {
			
			
				gen afterXtreatmentX`sample' = (`sample' == 1 & afterXtreatment == 1)
			
					foreach x in boy educ_av educ_em m_ahim  eth_aa eth_ea eth_imm eth_fsu eth_eth `reform_dummies'  {
						
						gen `x'X`sample' = `x' * `sample' 
					}
				
				local controlsX`sample' "boyX`sample' educ_avX`sample' educ_emX`sample' m_ahimX`sample' eth_aaX`sample' eth_eaX`sample' eth_immX`sample' eth_fsuX`sample' eth_ethX`sample'"
				local reformsX`sample' "d_pay_mealX`sample' d_pay_electricityX`sample' d_pay_healthX`sample' d_pay_laundryX`sample'"
				
					foreach year in _YyearRelev_1996 _YyearRelev_1999 _YyearRelev_2000 {
						
						gen `year'X`sample' = `year' * `sample'
						
					}
	
				foreach var of varlist `depvars' {
		
					//DID + year dummies + individual controls + kibbutz FE
					di ""
					di "**********************************************************************************"
					di ""
					di "DID + year dummies + individual controls + kibbutz FE"
					di ""
					di "Outcome: `var'"
					di ""
					di "Cohorts: ``set'After', ``set'Before'"
					di ""
					di "Sample: `sample' == 1 OR 0"
					di ""
					di "**********************************************************************************"
					
					di ""
					di "xi: reg `var' afterXtreatment afterXtreatmentX`sample' `sample' `controls' `controlsX`sample'' _Iyear* i.Rel*I.`sample' if (before | after) & (treatment==1| control==1), `cluster'"
					xi: reg `var' afterXtreatment afterXtreatmentX`sample' `sample' `controls' `controlsX`sample'' _Yyear* i.Rel*I.`sample' if (before | after) & (treatment==1| control==1), `cluster'
					di ""

					local B6_`var'_`sample'  = _b[afterXtreatment]
					local SE6_`var'_`sample' = _se[afterXtreatment]
					
					local B7_`var'_`sample'  = _b[afterXtreatment] + _b[afterXtreatmentX`sample']
					
					matrix V = e(V)
					
					local SE7_`var'_`sample' = sqrt(V[1,1] + V[2,2] + 2 * V[2,1]) 
					
					test afterXtreatmentX`sample' = 0 
					
					local F1_`var'_`sample' = r(F)
					local P1_`var'_`sample' = r(p)
					
										di ""
					di "xi: reg `var' afterXtreatment afterXtreatmentX`sample' `sample' `controls' `reform_dummies' `controlsX`sample'' `reformsX`sample'' _Iyear* i.Rel*I.`sample' if (before | after) & (treatment==1| control==1), `cluster'"
					xi: reg `var' afterXtreatment afterXtreatmentX`sample' `sample' `controls' `reform_dummies' `controlsX`sample'' `reformsX`sample'' _Yyear* i.Rel*I.`sample' if (before | after) & (treatment==1| control==1), `cluster'
					di ""

					local B8_`var'_`sample'  = _b[afterXtreatment]
					local SE8_`var'_`sample' = _se[afterXtreatment]
					
					local B9_`var'_`sample'  = _b[afterXtreatment] + _b[afterXtreatmentX`sample']
					
					matrix V = e(V)
					
					local SE9_`var'_`sample' = sqrt(V[1,1] + V[2,2] + 2 * V[2,1]) 
					
					test afterXtreatmentX`sample' = 0 
					
					local F2_`var'_`sample' = r(F)
					local P2_`var'_`sample' = r(p)
		
				}

			post values ("Cont. DID `sample' 1")	 (`B6_graduate_`sample'')  (`B6_wmean_`sample'')    (`B6_zakai_bagrut_`sample'')    (`B6_university_`sample'') (`B6_score_`sample'') (.) (`B8_graduate_`sample'')  (`B8_wmean_`sample'')    (`B8_zakai_bagrut_`sample'')    (`B8_university_`sample'') (`B8_score_`sample'')
			post values ("")	                 	 (`SE6_graduate_`sample'')  (`SE6_wmean_`sample'')    (`SE6_zakai_bagrut_`sample'')    (`SE6_university_`sample'') (`SE6_score_`sample'') (.) (`SE8_graduate_`sample'')  (`SE8_wmean_`sample'')    (`SE8_zakai_bagrut_`sample'')    (`SE8_university_`sample'') (`SE8_score_`sample'')
			post values ("")                     (.)		       			   (.)		     				(.)                   				(.) (.)  (.) (.) (.) (.) (.) (.) 			  
			
			post values ("Cont. DID `sample' 0")	 (`B7_graduate_`sample'')  (`B7_wmean_`sample'')    (`B7_zakai_bagrut_`sample'')    (`B7_university_`sample'') (`B7_score_`sample'') (.) (`B9_graduate_`sample'')  (`B9_wmean_`sample'')    (`B9_zakai_bagrut_`sample'')    (`B9_university_`sample'') (`B9_score_`sample'')
			post values ("")	                 	 (`SE7_graduate_`sample'')  (`SE7_wmean_`sample'')    (`SE7_zakai_bagrut_`sample'')    (`SE7_university_`sample'') (`SE7_score_`sample'') (.) (`SE9_graduate_`sample'')  (`SE9_wmean_`sample'')    (`SE9_zakai_bagrut_`sample'')    (`SE9_university_`sample'') (`SE9_score_`sample'')
			post values ("")                     (.)		       			   (.)		     				(.)                   				(.) (.)  (.) (.) (.) (.) (.) (.) 			  
			           
			post values ("F `sample'")	 		     (`F1_graduate_`sample'')    (`F1_wmean_`sample'')    (`F1_zakai_bagrut_`sample'')     (`F1_university_`sample'')	 (`F1_score_`sample'')   (.)  (`F2_graduate_`sample'')    (`F2_wmean_`sample'')    (`F2_zakai_bagrut_`sample'')     (`F2_university_`sample'')	 (`F2_score_`sample'') 
			post values ("P `sample'")	 		     (`P1_graduate_`sample'')    (`P1_wmean_`sample'')    (`P1_zakai_bagrut_`sample'')     (`P1_university_`sample'')	 (`P1_score_`sample'')   (.)  (`P2_graduate_`sample'')    (`P2_wmean_`sample'')    (`P2_zakai_bagrut_`sample'')     (`P2_university_`sample'')	 (`P2_score_`sample'')	
			
			}

		}
	
	}
}

postclose values 
/*************************************************************
V. Reformat from dta to csv
**************************************************************/

use "results\automatic\\${name}", clear

outsheet using "results\automatic\\${name}.csv", replace comma

erase "results\automatic\\${name}.dta"

cap log close
