/************************************************

Creator: Elior

Created: Febuary 2014

Description: This file creates Table 5: The Effect
             of the Pay Reform on Post Secondary Schooling
			 
*************************************************/

clear all
set mem 500m
set matsize 800
set more off
set logtype text

global name Table_5

local today = "$S_DATE"
local day = word("`today'",1)
local month = word("`today'",2)
local year = substr(word("`today'",3),3,2)
if `day' < 10 local `day' = "0`day'"

/**************************************************
I. ENTER THE PATH NAME WHERE THE DATA FILE IS FOUND
***************************************************/

cd "C:\Users\msvictor3\Dropbox\Work\Kibbutzim\Kibbutzim_ECMA"
use data\kibbutzim, clear

/**************************************************
II. DEFINE `after' AND `before' 
***************************************************/

local act9596_9900Before "1995 1996"
local act9596_9900After "1999 2000"

/**************************************************
III. DEFINE SAMPLES 
***************************************************/

// FULL SAMPLE
local allobs "id != ."

// BY GENDER
gen girl = (boy == 0)

/**************************************************
III. GENERATE POST SECONDARY DEPENDENT VARIABLES 
***************************************************/
gen E = (educ > 0 & educ != . )
rename educ_uni uni
gen A = (uni > 0 & uni != .)
rename educ_academiccollege col
gen B = (col > 0 & col != .)
rename educ_teacherscollege teach
gen C = (teach > 0 & teach != .)

/**************************************************
IV. RUN DID REGRESSIONS - PART I 
***************************************************/

local depvars "E A B C educ uni col teach"

local controls "boy educ_av educ_em m_ahim eth_*"

local reform_dummies "d_pay_meal d_pay_electricity d_pay_health d_pay_laundry"

local cluster "cluster(kibbutz)"

local tgroups "ref9800"

local cgroups "ref0304"

local samples "allobs"

local sets "act9596_9900"

/**************************************************
V. OPEN LOG FILE 
***************************************************/
cap log close
log using "logs\\${name}_`day'`month'`year'.log", replace

postfile values str50 rowKey E A B C gap educ uni col teach using "results\automatic\\${name}", replace

foreach treatment in `tgroups' {

	foreach control in `cgroups' {
	
		foreach sample in `samples' {
		
			foreach set in `sets' {
			
				// Define after and before periods
				cap drop after
				cap drop before
				cap drop treatment
				cap drop control
				cap drop afterXtreatment
				cap drop yearRelevant
				cap drop _Iyear*
				
				egen after = anymatch(year), values(``set'After')
				egen before = anymatch(year), values (``set'Before')
				
				gen treatment = `treatment'
				gen control = `control' 
				gen afterXtreatment = after * treatment
				
				// Create year dummies
				di ""
				gen yearRelevant = year if (before | after)
				
				di ""
				di "xi i.yearRelevant"
				xi i.yearRelevant
				
					foreach var of varlist `depvars' {
						
						// DID + year dummies + individual controls + kibbutz FE
						di ""
						di "*********************************************************"
						di ""
						di "DID + year dummies + individual controls + kibbutz FE"
						di ""
						di "Outcome: `var'"
						di ""
						di "Cohorts: ``set'After', ``set'Before'
						di ""
						di "Sample: `sample'"
						di ""
						di "*********************************************************"
						di ""
						
						di "areg `var' afterXtreatment _Iyear* `controls' if (before | after) & (treatment | control) & ``sample'', absorb(kibbutz) `cluster'"
						areg `var' afterXtreatment _Iyear* `controls' if (before | after) & (treatment | control) & ``sample'', absorb(kibbutz) `cluster'
						
						loca B1_`var' = _b[afterXtreatment]
						loca SE1_`var' = _se[afterXtreatment]
						
						// INCLUDING REFORMS DUMMIES AS CONTROLS IN THE DID REGRESSION
						di "areg `var' afterXtreatment _Iyear* `controls' `reform_dummies' if (before | after) & (treatment | control) & ``sample'', absorb(kibbutz) `cluster'"
						areg `var' afterXtreatment _Iyear* `controls' `reform_dummies' if (before | after) & (treatment | control) & ``sample'', absorb(kibbutz) `cluster'
						
						loca B2_`var' = _b[afterXtreatment]
						loca SE2_`var' = _se[afterXtreatment]
						
				}
			}
		}
	}
}

post values ("Controlled DID") (`B1_E') (`B1_A') (`B1_B') (`B1_C') (.) (`B1_educ') (`B1_uni') (`B1_col') (`B1_teach')
post values ("Cluster SE") (`SE1_E') (`SE1_A') (`SE1_B') (`SE1_C') (.) (`SE1_educ') (`SE1_uni') (`SE1_col') (`SE1_teach')
post values ("") (.) (.) (.) (.) (.) (.) (.) (.) (.)

/**************************************************
IV. RUN DID REGRESSIONS - PART I 
***************************************************/
local depvars "E A B S educ uni col semeng"

local controls "boy educ_av educ_em m_ahim eth_*"

local reform_dummies "d_pay_meal d_pay_electricity d_pay_health d_pay_laundry"

local cluster "cluster(kibbutz)"

local tgroups "ref9800"

local cgroups "ref0304"

local samples "girl"

local sets "act9596_9900"

foreach treatment in `tgroups' {

	foreach control in `cgroups' {
		
			foreach set in `sets' {
			
				// Define after and before periods
				cap drop after
				cap drop before
				cap drop treatment
				cap drop control
				cap drop afterXtreatment
				cap drop yearRelevant
				cap drop _Yyear*
				
				egen after = anymatch(year), values(``set'After')
				egen before = anymatch(year), values (``set'Before')
				
				gen treatment = `treatment'
				gen control = `control' 
				gen afterXtreatment = after * treatment
				
				// Create year dummies
				di ""
				gen yearRelevant = year if (before | after)
				
				di ""
				di "xi i.yearRelevant"
				xi i.yearRelevant, prefix(_Y)
				
				// CREATE KIBBUTZ DUMMIES
				cap drop Rel 
				gen Rel = kibbutz if (before | after) & (treatment | control)
				xi i.Rel, prefix(_Kib)
				
					foreach sample in `samples' {
					
						gen afterXtreatmentX`sample' = (`sample' == 1 & afterXtreatment == 1)
						
							foreach x in boy educ_av educ_em m_ahim eth_aa eth_ea eth_imm eth_fsu eth_eth `reform_dummies' {
							
								gen `x'X`sample' = `x' * `sample' 
							}
						
						local controlsX`sample' "boyX`sample' educ_avX`sample' educ_emX`sample' m_ahimX`sample' eth_aaX`sample' eth_eaX`sample' eth_immX`sample' eth_fsuX`sample' eth_ethX`sample'"
						local reformsX`sample' "d_pay_mealX`sample' d_pay_electricityX`sample' d_pay_healthX`sample' d_pay_laundryX`sample'"
				
						foreach year in _YyearRelev_1996 _YyearRelev_1999 _YyearRelev_2000 {
							
							gen `year'X`sample' = `year' * `sample' 
						}

						foreach var of varlist `depvars' {
							
							// DID + year dummies + individual controls + kibbutz FE
							di ""
							di "*********************************************************"
							di ""
							di "DID + year dummies + individual controls + kibbutz FE"
							di ""
							di "Outcome: `var'"
							di ""
							di "Cohorts: ``set'After', ``set'Before'"
							di ""
							di "Sample: `sample' == 1 OR 0"
							di ""
							di "*********************************************************"
							di ""
							
							di "xi: reg `var' afterXtreatment afterXtreatmentX`sample' `sample' `controls' `controlsX`sample'' _Yyear* i.Rel*I.`sample' if (before | after) & (treatment | control),  `cluster'"
							xi: reg `var' afterXtreatment afterXtreatmentX`sample' `sample' `controls' `controlsX`sample'' _Yyear* i.Rel*I.`sample' if (before | after) & (treatment | control),  `cluster'
							
							local B3_`var' = _b[afterXtreatment]
							local SE3_`var' = _se[afterXtreatment]
							
							local B4_`var' = _b[afterXtreatment] + _b[afterXtreatmentX`sample']
							
							matrix V = e(V)
							
							local SE4_`var' = sqrt(V[1,1] + V[2,2] + 2 * V[2,1])
							
							test afterXtreatmentX`sample' = 0
							
							local F1_`var' = r(F)
							local P1_`var' = r(p)
							
							// INCLUDING REFORMS DUMMIES AS CONTROLS IN THE DID REGRESSION
							di "xi: reg `var' afterXtreatment afterXtreatmentX`sample' `sample' `controls' `reform_dummies' `controlsX`sample'' `reformsX`sample'' _Yyear* i.Rel*I.`sample' if (before | after) & (treatment | control),  `cluster'"
							xi: reg `var' afterXtreatment afterXtreatmentX`sample' `sample' `controls' `reform_dummies' `controlsX`sample'' `reformsX`sample'' _Yyear* i.Rel*I.`sample' if (before | after) & (treatment | control),  `cluster'
							
							local B5_`var' = _b[afterXtreatment]
							local SE5_`var' = _se[afterXtreatment]
							
							local B6_`var' = _b[afterXtreatment] + _b[afterXtreatmentX`sample']
							
							matrix V = e(V)
							
							local SE6_`var' = sqrt(V[1,1] + V[2,2] + 2 * V[2,1])
							
							test afterXtreatmentX`sample' = 0
							
							local F2_`var' = r(F)
							local P2_`var' = r(p)
					}
				}	
			}
		}
	}

post values ("Controlled DID `sample' 1") (`B3_E') (`B3_A') (`B3_B') (`B3_C') (.) (`B3_educ') (`B3_uni') (`B3_col') (`B3_teach')
post values ("Cluster SE") (`SE3_E') (`SE3_A') (`SE3_B') (`SE3_C') (.) (`SE3_educ') (`SE3_uni') (`SE3_col') (`SE3_teach')
post values ("") (.) (.) (.) (.) (.) (.) (.) (.) (.)

post values ("Controlled DID `sample' 0") (`B4_E') (`B4_A') (`B4_B') (`B4_C') (.) (`B4_educ') (`B4_uni') (`B4_col') (`B4_teach')
post values ("Cluster SE") (`SE4_E') (`SE4_A') (`SE4_B') (`SE4_C') (.) (`SE4_educ') (`SE4_uni') (`SE4_col') (`SE4_teach')
post values ("") (.) (.) (.) (.) (.) (.) (.) (.) (.)

post values ("F `sample'") (`F1_E') (`F1_A') (`F1_B') (`F1_C') (.) (`F1_educ') (`F1_uni') (`F1_col') (`F1_teach')
post values ("P `sample'") (`P1_E') (`P1_A') (`P1_B') (`P1_C') (.) (`P1_educ') (`P1_uni') (`P1_col') (`P1_teach')
post values ("") (.) (.) (.) (.) (.) (.) (.) (.) (.)

post values ("Controlled DID with Reforms") (`B2_E') (`B2_A') (`B2_B') (`B2_C') (.) (`B2_educ') (`B2_uni') (`B2_col') (`B2_teach')
post values ("Cluster SE") (`SE2_E') (`SE2_A') (`SE2_B') (`SE2_C') (.) (`SE2_educ') (`SE2_uni') (`SE2_col') (`SE2_teach')
post values ("") (.) (.) (.) (.) (.) (.) (.) (.) (.)

post values ("Controlled DID with reforms `sample' 1") (`B5_E') (`B5_A') (`B5_B') (`B5_C') (.) (`B5_educ') (`B5_uni') (`B5_col') (`B5_teach')
post values ("Cluster SE") (`SE5_E') (`SE5_A') (`SE5_B') (`SE5_C') (.) (`SE5_educ') (`SE5_uni') (`SE5_col') (`SE5_teach')
post values ("") (.) (.) (.) (.) (.) (.) (.) (.) (.)

post values ("Controlled DID with reforms `sample' 0") (`B6_E') (`B6_A') (`B6_B') (`B6_C') (.) (`B6_educ') (`B6_uni') (`B6_col') (`B6_teach')
post values ("Cluster SE") (`SE6_E') (`SE6_A') (`SE6_B') (`SE6_C') (.) (`SE6_educ') (`SE6_uni') (`SE6_col') (`SE6_teach')
post values ("") (.) (.) (.) (.) (.) (.) (.) (.) (.)

post values ("F `sample'") (`F2_E') (`F2_A') (`F2_B') (`F2_C') (.) (`F2_educ') (`F2_uni') (`F2_col') (`F2_teach')
post values ("P `sample'") (`P2_E') (`P2_A') (`P2_B') (`P2_C') (.) (`P2_educ') (`P2_uni') (`P2_col') (`P2_teach')
post values ("") (.) (.) (.) (.) (.) (.) (.) (.) (.)

postclose values

/**************************************************
V. REFORMAT DATA TO CSV 
***************************************************/

use "results\automatic\\${name}", clear

outsheet using "results\automatic\\${name}.csv", replace comma

erase "results\automatic\\${name}.dta"

cap log close
